==> usrp-0.5.tar.gz: usrp-0.5/host/swig/usrp_prims.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _usrp_prims

def _swig_setattr(self,class_type,name,value):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    self.__dict__[name] = value

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


ULS_ERROR = _usrp_prims.ULS_ERROR
ULS_OK = _usrp_prims.ULS_OK
ULS_ALREADY_LOADED = _usrp_prims.ULS_ALREADY_LOADED

usrp_one_time_init = _usrp_prims.usrp_one_time_init

usrp_rescan = _usrp_prims.usrp_rescan

usrp_find_device = _usrp_prims.usrp_find_device

usrp_usrp_p = _usrp_prims.usrp_usrp_p

usrp_usrp0_p = _usrp_prims.usrp_usrp0_p

usrp_usrp1_p = _usrp_prims.usrp_usrp1_p

usrp_fx2_p = _usrp_prims.usrp_fx2_p

usrp_unconfigured_usrp_p = _usrp_prims.usrp_unconfigured_usrp_p

usrp_configured_usrp_p = _usrp_prims.usrp_configured_usrp_p

usrp_open_cmd_interface = _usrp_prims.usrp_open_cmd_interface

usrp_open_rx_interface = _usrp_prims.usrp_open_rx_interface

usrp_open_tx_interface = _usrp_prims.usrp_open_tx_interface

usrp_close_interface = _usrp_prims.usrp_close_interface

usrp_load_firmware = _usrp_prims.usrp_load_firmware

usrp_load_firmware_nth = _usrp_prims.usrp_load_firmware_nth

usrp_load_fpga = _usrp_prims.usrp_load_fpga

usrp_load_standard_bits = _usrp_prims.usrp_load_standard_bits
FR_RX_FREQ_0 = _usrp_prims.FR_RX_FREQ_0
FR_RX_FREQ_1 = _usrp_prims.FR_RX_FREQ_1
FR_RX_FREQ_2 = _usrp_prims.FR_RX_FREQ_2
FR_RX_FREQ_3 = _usrp_prims.FR_RX_FREQ_3
FR_TX_FREQ_0 = _usrp_prims.FR_TX_FREQ_0
FR_TX_FREQ_1 = _usrp_prims.FR_TX_FREQ_1
FR_TX_FREQ_2 = _usrp_prims.FR_TX_FREQ_2
FR_TX_FREQ_3 = _usrp_prims.FR_TX_FREQ_3
FR_INTERP_RATE = _usrp_prims.FR_INTERP_RATE
FR_DECIM_RATE = _usrp_prims.FR_DECIM_RATE
FR_TX_SAMPLE_RATE_DIV = _usrp_prims.FR_TX_SAMPLE_RATE_DIV
FR_RX_SAMPLE_RATE_DIV = _usrp_prims.FR_RX_SAMPLE_RATE_DIV
FR_ADC_OFFSET_3_2 = _usrp_prims.FR_ADC_OFFSET_3_2
FR_ADC_OFFSET_1_0 = _usrp_prims.FR_ADC_OFFSET_1_0
FR_DAC_OFFSET_3_2 = _usrp_prims.FR_DAC_OFFSET_3_2
FR_DAC_OFFSET_1_0 = _usrp_prims.FR_DAC_OFFSET_1_0
FR_MASTER_CTRL = _usrp_prims.FR_MASTER_CTRL
bmFR_MC_ENABLE_TX = _usrp_prims.bmFR_MC_ENABLE_TX
bmFR_MC_ENABLE_RX = _usrp_prims.bmFR_MC_ENABLE_RX
bmFR_MC_RESET_TX = _usrp_prims.bmFR_MC_RESET_TX
bmFR_MC_RESET_RX = _usrp_prims.bmFR_MC_RESET_RX
FR_OE_0 = _usrp_prims.FR_OE_0
FR_OE_1 = _usrp_prims.FR_OE_1
FR_OE_2 = _usrp_prims.FR_OE_2
FR_OE_3 = _usrp_prims.FR_OE_3
FR_IO_0 = _usrp_prims.FR_IO_0
FR_IO_1 = _usrp_prims.FR_IO_1
FR_IO_2 = _usrp_prims.FR_IO_2
FR_IO_3 = _usrp_prims.FR_IO_3
FR_MODE = _usrp_prims.FR_MODE
bmFR_MODE_NORMAL = _usrp_prims.bmFR_MODE_NORMAL
bmFR_MODE_LOOPBACK = _usrp_prims.bmFR_MODE_LOOPBACK
bmFR_MODE_RX_COUNTING = _usrp_prims.bmFR_MODE_RX_COUNTING

usrp_write_fpga_reg = _usrp_prims.usrp_write_fpga_reg

usrp_read_fpga_reg = _usrp_prims.usrp_read_fpga_reg

usrp_set_fpga_reset = _usrp_prims.usrp_set_fpga_reset

usrp_set_fpga_tx_enable = _usrp_prims.usrp_set_fpga_tx_enable

usrp_set_fpga_rx_enable = _usrp_prims.usrp_set_fpga_rx_enable

usrp_set_fpga_tx_reset = _usrp_prims.usrp_set_fpga_tx_reset

usrp_set_fpga_rx_reset = _usrp_prims.usrp_set_fpga_rx_reset

usrp_set_sleep_bits = _usrp_prims.usrp_set_sleep_bits

usrp_set_led = _usrp_prims.usrp_set_led

usrp_check_rx_overrun = _usrp_prims.usrp_check_rx_overrun

usrp_check_tx_underrun = _usrp_prims.usrp_check_tx_underrun

usrp_i2c_write = _usrp_prims.usrp_i2c_write

usrp_i2c_read = _usrp_prims.usrp_i2c_read

usrp_spi_write = _usrp_prims.usrp_spi_write

usrp_spi_read = _usrp_prims.usrp_spi_read

usrp_9862_write = _usrp_prims.usrp_9862_write

usrp_9862_read = _usrp_prims.usrp_9862_read

usrp_eeprom_write = _usrp_prims.usrp_eeprom_write

usrp_eeprom_read = _usrp_prims.usrp_eeprom_read

usrp_write_aux_dac = _usrp_prims.usrp_write_aux_dac

usrp_read_aux_adc = _usrp_prims.usrp_read_aux_adc

==> usrp_0.8.orig.tar.gz: usrp-0.8/host/swig/usrp_prims.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _usrp_prims

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


ULS_ERROR = _usrp_prims.ULS_ERROR
ULS_OK = _usrp_prims.ULS_OK
ULS_ALREADY_LOADED = _usrp_prims.ULS_ALREADY_LOADED

usrp_one_time_init = _usrp_prims.usrp_one_time_init

usrp_rescan = _usrp_prims.usrp_rescan

usrp_usrp_p = _usrp_prims.usrp_usrp_p

usrp_usrp0_p = _usrp_prims.usrp_usrp0_p

usrp_usrp1_p = _usrp_prims.usrp_usrp1_p

usrp_usrp2_p = _usrp_prims.usrp_usrp2_p

usrp_fx2_p = _usrp_prims.usrp_fx2_p

usrp_unconfigured_usrp_p = _usrp_prims.usrp_unconfigured_usrp_p

usrp_configured_usrp_p = _usrp_prims.usrp_configured_usrp_p

usrp_open_cmd_interface = _usrp_prims.usrp_open_cmd_interface

usrp_open_rx_interface = _usrp_prims.usrp_open_rx_interface

usrp_open_tx_interface = _usrp_prims.usrp_open_tx_interface

usrp_close_interface = _usrp_prims.usrp_close_interface

usrp_load_firmware = _usrp_prims.usrp_load_firmware

usrp_load_firmware_nth = _usrp_prims.usrp_load_firmware_nth

usrp_load_fpga = _usrp_prims.usrp_load_fpga

usrp_load_standard_bits = _usrp_prims.usrp_load_standard_bits
FR_TX_SAMPLE_RATE_DIV = _usrp_prims.FR_TX_SAMPLE_RATE_DIV
FR_RX_SAMPLE_RATE_DIV = _usrp_prims.FR_RX_SAMPLE_RATE_DIV
FR_ADC_OFFSET_3_2 = _usrp_prims.FR_ADC_OFFSET_3_2
FR_ADC_OFFSET_1_0 = _usrp_prims.FR_ADC_OFFSET_1_0
FR_MASTER_CTRL = _usrp_prims.FR_MASTER_CTRL
bmFR_MC_ENABLE_TX = _usrp_prims.bmFR_MC_ENABLE_TX
bmFR_MC_ENABLE_RX = _usrp_prims.bmFR_MC_ENABLE_RX
bmFR_MC_RESET_TX = _usrp_prims.bmFR_MC_RESET_TX
bmFR_MC_RESET_RX = _usrp_prims.bmFR_MC_RESET_RX
FR_OE_0 = _usrp_prims.FR_OE_0
FR_OE_1 = _usrp_prims.FR_OE_1
FR_OE_2 = _usrp_prims.FR_OE_2
FR_OE_3 = _usrp_prims.FR_OE_3
FR_IO_0 = _usrp_prims.FR_IO_0
FR_IO_1 = _usrp_prims.FR_IO_1
FR_IO_2 = _usrp_prims.FR_IO_2
FR_IO_3 = _usrp_prims.FR_IO_3
FR_MODE = _usrp_prims.FR_MODE
bmFR_MODE_NORMAL = _usrp_prims.bmFR_MODE_NORMAL
bmFR_MODE_LOOPBACK = _usrp_prims.bmFR_MODE_LOOPBACK
bmFR_MODE_RX_COUNTING = _usrp_prims.bmFR_MODE_RX_COUNTING
FR_INTERP_RATE = _usrp_prims.FR_INTERP_RATE
FR_DECIM_RATE = _usrp_prims.FR_DECIM_RATE
FR_RX_FREQ_0 = _usrp_prims.FR_RX_FREQ_0
FR_RX_FREQ_1 = _usrp_prims.FR_RX_FREQ_1
FR_RX_FREQ_2 = _usrp_prims.FR_RX_FREQ_2
FR_RX_FREQ_3 = _usrp_prims.FR_RX_FREQ_3
FR_RX_MUX = _usrp_prims.FR_RX_MUX
FR_TX_MUX = _usrp_prims.FR_TX_MUX

usrp_write_fpga_reg = _usrp_prims.usrp_write_fpga_reg

usrp_read_fpga_reg = _usrp_prims.usrp_read_fpga_reg

usrp_set_fpga_reset = _usrp_prims.usrp_set_fpga_reset

usrp_set_fpga_tx_enable = _usrp_prims.usrp_set_fpga_tx_enable

usrp_set_fpga_rx_enable = _usrp_prims.usrp_set_fpga_rx_enable

usrp_set_fpga_tx_reset = _usrp_prims.usrp_set_fpga_tx_reset

usrp_set_fpga_rx_reset = _usrp_prims.usrp_set_fpga_rx_reset

usrp_set_sleep_bits = _usrp_prims.usrp_set_sleep_bits

usrp_set_led = _usrp_prims.usrp_set_led

usrp_check_rx_overrun = _usrp_prims.usrp_check_rx_overrun

usrp_check_tx_underrun = _usrp_prims.usrp_check_tx_underrun

usrp_i2c_write = _usrp_prims.usrp_i2c_write

usrp_i2c_read = _usrp_prims.usrp_i2c_read

usrp_spi_write = _usrp_prims.usrp_spi_write

usrp_spi_read = _usrp_prims.usrp_spi_read

usrp_9862_write = _usrp_prims.usrp_9862_write

usrp_9862_read = _usrp_prims.usrp_9862_read

usrp_eeprom_write = _usrp_prims.usrp_eeprom_write

usrp_eeprom_read = _usrp_prims.usrp_eeprom_read

usrp_write_aux_dac = _usrp_prims.usrp_write_aux_dac

usrp_read_aux_adc = _usrp_prims.usrp_read_aux_adc

usrp_find_device = _usrp_prims.usrp_find_device
